********************
*** PREPARE DATA ***
********************
	
	**************
	*** GALLUP ***
	**************
	
		import excel "$input/GallupAnalytics_Export_20170117_163428.xlsx", firstrow clear sheet("Gay or Lesbian People")
		drop if missing(D)
		dropmiss, force 
		drop D E
		rename (GALLUP C F G H I) (country year goodplace badplace dk N)
		drop if _n == 1
		destring year goodplace badplace dk N, replace
		replace country = "Democratic Republic of the Congo" if country == "Congo (Kinshasa)"
		mmerge country using "$input/codes_masterlist.dta", ukeep(wb_ccode)
		keep if _merge == 3
		rename wb_ccode ccode
		drop _merge
		compress
		save "$output/gallup.dta", replace
		
	***********
	*** WVS ***
	***********
		
		use "$input/WVS_Longitudinal_1981_2014_stata_v2015_04_18.dta", clear
		
		*** Replace India Results for Wave 6
			drop if S003 == 356 & S002 == 6
			preserve
				tempfile India
				use "$input/WV6_Stata_v_2016_01_01.dta", clear
				keep if V2 == 356
				drop if V262 == 2014
				*** Rename variables to match
				rename (V2 V1 V262 V258 V242 V240 V241 V57 V58 V248 V239 V256 V40 V203 V37 V41 V205 V206)	///
				(S003 S002 S020 S018 X003 X001 X002 X007 X011 X025R X047 X048WVS A124_09 F118 A124_02 A124_12 F121 F135A)
				keep S003 S002 S020 S018 X003 X001 X002 X007 X011 X025R X047 X048WVS A124_09 F118
				save `India'
			restore
			append using `India'
			
		*** Clean Country Names
			keep S003 S002 S020 S018 X003 X001 X002 X007 X011 X025R X047 X048WVS A124_09 F118 A124_02 A124_12 F121 F135A
			decode S003, generate(country)
			replace country = "Bosnia & Herzegovina" if country == "Bosnia"
			replace country = "United Kingdom" if country == "Great Britain"
			replace country = "Serbia" if country == "Serbia and Montenegro"
			mmerge country using "$input/codes_masterlist.dta", ukeep(wb_ccode)
			drop if _merge == 2
			drop _merge S003
			rename wb_ccode ccode
			rename (S020 S018 S002 X001 X002 X003 X007 X011 X047 X048WVS F118 A124_09 X025R A124_02 A124_12 F121 F135A) 	///
				(year weight wave sex birthyear age marital children income region justifiable neighbors edlevel neighbors_race neighbors_rel just_div just_sbmar)
		
		*** Clean key variables
			foreach var in neighbors neighbors_race neighbors_rel {
				replace `var' = . if `var' < 0 | `var' == 2
			}
			*** Redefine neighbors so higher is positive norms
				foreach var in neighbors neighbors_race neighbors_rel {	
					replace neighbors = neighbors + 1
					replace neighbors = 0 if neighbors == 2
				}
			foreach var in justifiable just_div just_sbmar {
				replace `var' = . if `var' < 1 
			}
			replace edlevel = . if edlevel > 3 | edlevel < 1
			gen uppered = 1 if edlevel == 3
			gen lowered = 1 if edlevel == 1
			foreach var in uppered lowered {
				replace `var' = 0 if missing(`var') & !missing(edlevel)
			}
			replace age =. if age < 13
			gen female = sex == 2
			drop sex
			replace birthyear =. if birthyear < 1890
			replace marital =. if marital < 1
			replace marital =. if marital == 7
			gen married= 1 if marital==1
			replace married = 0 if missing(married) & !missing(marital)
			drop marital
			replace children =. if children < 0
			egen ccodeid = group(ccode)
			
		*** Label variables	
			label var female "Female"
			label var married "Married"
			label var ccodeid "Country"
			label var uppered "Upper Ed."
			label var lowered "Lower Ed."
	
		save "$output/wvs.dta", replace
		
	***************	
	*** ILLEGAL ***
	***************
		
		import excel "$input/Homosexuality Laws.xlsx", firstrow clear
		replace never_legal = 0 if missing(never_legal)
		mmerge ccode using "$input/globaldb.dta", ukeep(ccode)
		keep if _merge == 3 | _merge == 1
		drop _merge
		save "$output/illegal.dta", replace

	************************
	*** COLONIAL HISTORY ***
	************************
		
		use "$input/ICOW Colonial History 1.0/coldata100.dta", clear
		gen britishcolony	= colruler==200
		gen spanishcolony	= colruler==230
		gen frenchcolony	= colruler==220
		gen ottomancolony	= colruler==640
		gen russiancolony	= colruler==365
		gen portuguesecolony = colruler==235
		rename name country
		keep country *colony
		replace country = "Ivory Coast" if country == "Cote d'Ivoire (Ivory Coast)"
		replace country = "Benin" if country == "Benin (Dahomey)"
		replace country = "China" if country == "China (PRC)"
		replace country = "Democratic Republic of the Congo" if country == "Dem. Rep. Congo (Zaire; Kinshasa)"
		replace country = "Timor Leste" if country == "East Timor (Timor-Leste)"
		replace country = "Egypt" if country == "Egypt (original)"
		replace country = "Germany" if country == "German Dem. Rep. (East)"
		drop if country == "German Fed. Rep. (West)" | country == "Germany (Prussia)"
		replace country = "Iran" if country == "Iran (Persia)"
		replace country = "Italy" if country == "Italy (Sardinia)"
		replace country = "South Korea" if country == "Korea (unified)"
		replace country = "Madagascar" if country == "Madagascar (Malagasy Rep.)"
		replace country = "North Korea" if country == "North Korea (DPRK)"
		replace country = "Vietnam" if country == "Republic of Vietnam (South)"
		drop if country == "Vietnam/Dem.Rep.Vietnam (North)" | country == "South Korea (ROK)"
		replace country = "Russia" if country == "Russia (USSR)"
		replace country = "Sri Lanka" if country == "Sri Lanka (Ceylon)"
		replace country = "Taiwan" if country == "Taiwan (ROC)"
		replace country = "Tanzania" if country == "Tanzania (Tanganyika)"
		drop if country == "Yemen People's Rep. (Aden / South)" | country == "Yemen Arab Rep. (Sanaa / North)"
		drop if country == "Zanzibar"
		replace country = "Zimbabwe" if country == "Zimbabwe (Rhodesia)"
		replace country = "Burkina Faso" if country == "Burkina Faso (Upper Volta)"
		replace country = "Serbia" if country == "Yugoslavia / Serbia & Montenegro"
		mmerge country using "$input/codes_masterlist.dta", ukeep(wb_ccode)
		keep if _merge == 3
		drop _merge country
		rename wb_ccode ccode
		save "$output/colonies.dta", replace
		
	******************
	*** WORLD BANK ***
	******************
			
		import delimited "$input/e5139066-a606-41ce-a747-d9e8bd15ff38_Data.csv", clear
		forval i = 5/61 {
			local year = 1955 + `i'
			rename v`i' value`year'
		}
		drop if _n == 1
		rename (v1 v2) (country ccode)
		replace v4 = "gdppc" if v4 == "NY.GDP.PCAP.PP.KD"
		replace v4 = "flfpr" if v4 == "SL.TLF.CACT.FE.ZS"
		drop v3
		drop if missing(ccode)
		reshape long value, i(country ccode v4) j(year)
		reshape wide value, i(country ccode year) j(v4) string
		rename value* *
		destring flfpr gdppc, force replace
		drop country
		save "$output/wb.dta", replace
