**************
*** GRAPHS ***
**************

	use "$output/illegal.dta", clear
	egen countryid = group(ccode)
	gen year = switch_year
	tsset countryid year
	replace year = 2018 if missing(year)
	tsfill, full
	drop if year == 2018
	gen legal = 0
	sort countryid switch_year
	by countryid: replace switch_year = switch_year[_n-1] if missing(switch_year) & !missing(switch_year[_n-1])
	replace legal = 1 if year >= switch_year
	gen illegal = legal==0
	collapse (sum) legal illegal, by(year)
	sort year
	gen total = legal+illegal
	tw (area total year if year > 1960) 		///
		(area illegal year if year > 1960),		///
		plotregion(style(none) lcolor(none)) 	///
		graphregion(fcol(white) lcol(white)) 	///
		xtitle("Year")	legend(order(1 "Legal" 	///
		2 "Illegal") cols(1) region(color(white) ///
		lcolor(none)) ring(0) position(2)		///
		bmargin(medium)) ytitle("Number of Countries")	///
		xlab(1960(10)2010)
	graph export "$figures/homosexuality_pctarea.pdf", replace
	
	use "$output/wvs.dta", clear
	mmerge ccode using "$output/illegal.dta"
	keep if _merge == 3
	gen group = "Never Legal" if never_legal==1
	bys ccode: egen minyear = min(year)
	bys ccode: egen maxyear = max(year)
	replace group = "Always Legal" if switch_year <= minyear
	replace group = "Never Legal" if switch_year >= maxyear
	replace group = "Before Reform" if switch_year <=year & missing(group)
	replace group = "After Reform" if switch_year >= year & missing(group)
	gen groupnum = 1 if group == "Never Legal"
	replace groupnum = 2 if group == "Before Reform"
	replace groupnum = 3 if group == "After Reform"
	replace groupnum = 4 if group == "Always Legal"
	collapse justifiable neighbors [pw=weight], by(ccode wave group groupnum)
	graph box justifiable, over(group, sort(groupnum)) ytitle("Justifiable")	///
		plotregion(style(none) lcolor(none)) 	///
		graphregion(fcol(white) lcol(white)) 
	graph export "$figures/justifiable_boxplots.pdf", replace	
	graph box neighbors, over(group, sort(groupnum)) ytitle("Neighbors")	///
		plotregion(style(none) lcolor(none)) 	///
		graphregion(fcol(white) lcol(white)) 
	graph export "$figures/neighbors_boxplots.pdf", replace
	
	use "$output/gallup.dta", clear
	levelsof ccode if year == 2006, local(countries)
	gen fix = 0
	foreach country of local countries {
		replace fix = 1 if ccode == "`country'"
	}
	bys ccode: egen numyears = sum(fix)
	keep if numyears == 11
	collapse *place, by(year)
	tw (line goodplace year, lcolor(blue))	///
		(line badplace year, lcolor(red)),	///
		plotregion(style(none) lcolor(none))	///
		graphregion(fcol(white) lcol(white))	///
		xtitle("Year") ytitle("Portion Believe")	///
		legend(order(1 "Good Place" 2 "Bad Place")	///
			cols(2) region(color(none) lcolor(none))	///
			ring(0) position(0) bmargin(medium))
	graph export "$figures/gallup_goodbad_lines.pdf", replace
