****************************
*** INDIVIDUAL LEVEL OLS ***
****************************
	
	use "$output/wvs.dta", clear
	mmerge ccode using "$output/colonies.dta"
	mmerge ccode using "$output/illegal.dta"
	mmerge ccode year using "$output/wb.dta"
	keep if _merge == 3
	replace gdppc = log(gdppc)
	label var gdppc "Log GDP per Capita Constant PPP"
	gen illegal = 1 if never_legal == 1
	replace illegal = 1 if year < switch_year & missing(illegal)
	replace illegal = 0 if year >= switch_year & missing(illegal)
	label var illegal "Homosexuality Illegal"
	bys ccode: egen maxwave = max(wave)
	keep if wave == maxwave
	collapse neighbors justifiable [pw=weight], by(ccode wave illegal britishcolony gdp)	
		foreach var in neighbors justifiable {
			reghdfe `var' illegal britishcolony gdp, a(wave)
			est store `var'_country
		}
		
	use "$output/wvs.dta", clear
	mmerge ccode using "$output/colonies.dta"
	mmerge ccode using "$output/illegal.dta"
	gen illegal = 1 if never_legal == 1
	replace illegal = 1 if year < switch_year & missing(illegal)
	replace illegal = 0 if year >= switch_year & missing(illegal)
	label var illegal "Homosexuality Illegal"
	gen gdppc = . // To get the labels right
	label var britishcolony "Former British Colony"
	label var gdppc "Log GDP per Capita Constant PPP"

		foreach var in neighbors justifiable {
			*** Create years variable
			summ year if !missing(`var')
			gen yearssince_`var' = year - `r(min)'
			label var yearssince_`var' "Years Since `r(min)'"
			reghdfe `var', a(ccodeid)
			est store `var'_val_fe
			reghdfe `var' illegal, a(ccodeid)
			est store `var'_illegal
			reghdfe `var' yearssince_`var', a(ccodeid) 
			est store `var'_yearssince
			reghdfe `var' yearssince_`var' female age, a(ccodeid) 
			est store `var'_val_sexage
			reghdfe `var' illegal yearssince_`var' female age income uppered lowered, a(ccodeid) 
			est store `var'_val_demog
		}

	*** Create Latex Tables
		foreach var in neighbors justifiable {
			esttab `var'_val_fe `var'_yearssince `var'_val_sexage `var'_val_demog `var'_country ///
				using "$tables/ols_`var'.tex", ///
				replace label star(* 0.05 ** 0.01) stats(N r2, fmt(0 3) ///
				layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") ///
				labels(`"Observations"' `"\(R^{2}\)"')) nomtitles notes 
		}	

*************************
*** COUNTRY LEVEL OLS ***
*************************
	
	use "$output/gallup.dta", clear	
	mmerge ccode using "$output/colonies.dta"
	keep if _merge == 3
	mmerge ccode using "$output/illegal.dta"
	keep if _merge == 3
	mmerge ccode year using "$output/wb.dta"
	keep if _merge == 3
	replace gdppc = log(gdppc)
	gen illegal = 1 if never_legal == 1
	replace illegal = 1 if year < switch_year & missing(illegal)
	replace illegal = 0 if year >= switch_year & missing(illegal)
	gen legal = 1 - illegal
	label var gdppc "Log GDP Per Capita"
	label var flfpr "Female Labor Force Participation Rate"
	label var britishcolony "Former British Colony"
	label var illegal "Homosexuality Illegal"
	label var goodplace "Good Place"
	label var badplace "Bad Place"
	label var legal "Homosexuality Legal"
	egen countryid = group(ccode)
	
	eststo clear
	reghdfe goodplace legal, a(year countryid) vce(cluster countryid)
	est store good
	reghdfe badplace legal, a(year countryid) vce(cluster countryid)
	est	store bad
	reghdfe goodplace legal if never_legal == 0, a(year countryid) vce(cluster countryid)
	est store goodrest
	reghdfe badplace legal if never_legal == 0, a(year countryid) vce(cluster countryid)
	est store badrest
	reghdfe goodplace legal gdppc if never_legal == 0, a(year countryid) vce(cluster countryid)
	est store goodrestgdppc 
	reghdfe badplace legal gdppc if never_legal == 0, a(year countryid) vce(cluster countryid)
	est store badrestgdppc
	esttab good bad goodrest badrest goodrestgdppc badrestgdppc ///
		using "$tables/gallup_ols.tex", ///
			replace label star(* 0.05 ** 0.01) stats(N r2_a_within, fmt(0 3) ///
			layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") ///
			labels(`"Observations"' `"\(R^{2}\)"')) notes 
		
	*** Pre-trends graph
		bys countryid: egen count = count(year)
		keep if count == 11 | switch_year > 2006
		gen always_legal = switch_year < 2006
		gen type = 1 if always_legal == 1
		replace type = 2 if never_legal == 1
		replace type = countryid if switch_year > 2006 & !missing(switch_year)
		collapse (mean) badplace goodplace, by(type year)
		
		tw (line badplace year if type==1, sort lcolor(black) lpattern(dash)) 		///
			(line badplace year if type==2, sort lcolor(black) lpattern(dot))	///
			(line badplace year if type==100, sort lcolor(blue))			///
			(line badplace year if type==103, sort lcolor(dkorange))		///
			(line badplace year if type==106, sort lcolor(emerald)),	///
			legend(cols(3) order( 3 "Nicaragua" ///
				4 "Nepal" 5 "Panama" 1 "Always Legal" 2 "Never Legal" ) region(lcolor(none)))	///
			plotregion(style(none) lcolor(none)) 	///
			graphregion(fcol(white) lcol(white))	///
			ytitle("Bad Place") xtitle("Year") xline(2008)	///
			xlabel(2006(1)2016) ylabel(.2(.1)1)
		graph export "$figures/pretrends_diffindiff.pdf", replace
		
	*** Colonies
		use "$output/gallup.dta", clear	
		bys ccode: egen maxyear = max(year)
		keep if year == maxyear
		mmerge ccode using "$output/colonies.dta"
		keep if _merge == 3
		mmerge ccode using "$output/illegal.dta"
		keep if _merge == 3
		label var britishcolony "British"
		label var spanishcolony "Spanish"
		label var frenchcolony "French"
		label var ottomancolony "Ottoman"
		label var russiancolony "Russian"
		label var portuguesecolony "Portuguese"
		eststo clear
		foreach colony of varlist *colony {
			local name = strproper(subinstr("`colony'","colony","",.))
			regress never_legal `colony'
			estimates store m`name'
		}
		local models = ""
		foreach colony of varlist *colony {	
			local name = strproper(subinstr("`colony'","colony","",.))
			local models `models' (m`name', mcolor(navy) msymbol(diamond) msize(small) lcolor(navy)  ciopts(lcol(navy)))	
		}
		coefplot `models', drop(_cons) legend(off) xline(0)		///
			plotregion(style(none) lcolor(none)) 	///
			graphregion(fcol(white) lcol(white))	///
			ytitle("Former Colonial Power") xtitle("Coefficient") 
		graph export "$figures/colonial_coefplot.pdf", replace

**************************
*** SUMMARY STATISTICS ***
**************************
	
	use "$output/wvs.dta", clear
	drop if missing(justifiable) & missing(neighbors)
	label var neighbors "Neighbors"
	label var justifiable "Justifiable"
	drop if wave == 1
	eststo clear
	bys wave: eststo: quietly estpost summarize neighbors justifiable [aw=weight], listwise
	esttab using "$tables/wvs_summstats.tex", 									///
		cells("mean(fmt(2)) sd(fmt(2))") booktabs label							///
		nonumber replace mtitles("Wave 2: 1989-1993" 							///
		"Wave 3: 1994-1998" "Wave 4: 1999-2004" "Wave 5: 2005-2009" 			///
		"Wave 6: 2010-2014") collabels("Mean" "SD") 
	
	use "$output/gallup.dta", clear	
	label var goodplace "Good Place"
	label var badplace "Bad Place"
	eststo clear
	keep if mod(year,2)==0
	bys year: eststo: quietly estpost summarize goodplace badplace, listwise
	esttab using "$tables/gallup_summstats.tex", 								///
		cells("mean(fmt(2)) sd(fmt(2))") booktabs label							///
		nonumber replace mtitles("2006" "2008" "2010" 		///
			"2012" "2014"  "2016") collabels("Mean" "SD") 
	
